==> ophcrack_2.3.4~debian.orig.tar.gz: ophcrack-2.3.4~debian/src/callbacks.h <==
/*

    Ophcrack is a Lanmanager/NTLM hash cracker based on the faster time-memory
    trade-off using rainbow tables. 
    
    Created with the help of: Maxime Mueller, Luca Wullschleger, Claude
    Hochreutiner, Andreas Huber and Etienne Dysli.

    Copyright 2006 Philippe Oechslin, Cedric Tissieres

    Ophcrack is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Ophcrack is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Ophcrack; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

    This program is released under the GPL with the additional exemption 
    that compiling, linking, and/or using OpenSSL is allowed.
*/

//"$Id: callbacks.h,v 2.2 2006/03/20 tissieres Exp $";

/* 
 * $Log: callbacks.h,v $
 * Revision 2.3  2006/07/21 tissieres
 * Help added
 *
 * Revision 2.2  2006/03/30 tissieres
 * Tables management simplified
 *
 * Revision 2.1  2005/12/06 tissieres
 * Added table modification functions
 *
 * Revision 2.0  2005/03/24 tissieres
 * Initial revision
 *
 */



void
on_load_file1_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);
void
on_launch1_toggled                     (GtkToggleToolButton *toggletoolbutton,
                                        gpointer         user_data);
void
on_exit1_activate                      (GtkMenuItem     *menuitem,
					gpointer         user_data);
void
on_ok_button1_clicked                  (GtkButton       *button,
                                        gpointer         user_data);
void create_model(void);
void update_statusbar(int k);

void
on_ok_button2_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_dump1_clicked                       (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

void
on_save_ok_button_clicked              (GtkButton   *button,
                                        gpointer         user_data);

void
on_save_button_clicked                  (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

void
on_cancel_button1_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_cancel_button1_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_ok_button1_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_cancel_button2_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_about_button_clicked                (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

void
on_about_close_button_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_from__sam_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_local_pwdump1_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_remote_pwdump1_activate             (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_remote_cancel_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_remote_ok_button_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_dialog_remote_dump_close            (GtkDialog       *dialog,
                                        gpointer         user_data);

void
on_filechooserdialog1_close            (GtkDialog       *dialog,
                                        gpointer         user_data);

void
on_filechooserdialog2_close            (GtkDialog       *dialog,
                                        gpointer         user_data);

void
on_fileselection_close                 (GtkDialog       *dialog,
                                        gpointer         user_data);

void
on_tablebutton_activate                (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

void
on_table_dialog_destroy                (GtkObject       *object,
                                        gpointer         user_data);

void
on_button_directory_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_tableselection_close                (GtkObject       *object,
                                        gpointer         user_data);

void
on_cancel_ts_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_ok_ts_clicked                       (GtkButton       *button,
                                        gpointer         user_data);

void
on_cancel_table_dialog_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_ok_table_dialog_clicked             (GtkButton       *button,
                                        gpointer         user_data);

void
on_load_single_hash1_activate          (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_cancel_load_hash_dialog_clicked     (GtkButton       *button,
                                        gpointer         user_data);

void
on_ok_load_hash_dialog_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_load_hash_dialog_destroy            (GtkObject       *object,
                                        gpointer         user_data);

void
on_deletebutton_clicked                (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

void
show_readahead_window(int num);

void
show_clean_windows(void);

void 
hide_readahead_window(void);

#ifdef LIVECD
void activate_launch_toggle (void);
#endif

void
on_help_button_clicked                 (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

void
on_help_window_close                   (GtkObject       *object,
                                        gpointer         user_data);

int change_tree(int hash);

void show_dialog(char *title, char *body);

==> ophcrack_2.4.1~debian.orig.tar.gz: ophcrack-2.4.1~debian/src/callbacks.h <==
/*

    Ophcrack is a Lanmanager/NTLM hash cracker based on the faster time-memory
    trade-off using rainbow tables. 
    
    Created with the help of: Maxime Mueller, Luca Wullschleger, Claude
    Hochreutiner, Andreas Huber and Etienne Dysli.

    Copyright 2006 Philippe Oechslin, Cedric Tissieres

    Ophcrack is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Ophcrack is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Ophcrack; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

    This program is released under the GPL with the additional exemption 
    that compiling, linking, and/or using OpenSSL is allowed.
*/

//"$Id: callbacks.h,v 2.2 2006/03/20 tissieres Exp $";

/* 
 * $Log: callbacks.h,v $
 * Revision 2.4.1 2007/08/02 tissieres
 * bugfix extract hash
 *
 * Revision 2.4  2007/06/21 oechslin
 * update_status_bar changed
 *
 * Revision 2.3  2006/07/21 tissieres
 * Help added
 *
 * Revision 2.2  2006/03/30 tissieres
 * Tables management simplified
 *
 * Revision 2.1  2005/12/06 tissieres
 * Added table modification functions
 *
 * Revision 2.0  2005/03/24 tissieres
 * Initial revision
 *
 */



void
on_load_file1_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);
void
on_launch1_toggled                     (GtkToggleToolButton *toggletoolbutton,
                                        gpointer         user_data);
void
on_exit1_activate                      (GtkMenuItem     *menuitem,
					gpointer         user_data);
void
on_ok_button1_clicked                  (GtkButton       *button,
                                        gpointer         user_data);
void create_model(void);
void update_statusbar(int msg, int k);

void
on_ok_button2_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_dump1_clicked                       (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

void
on_save_ok_button_clicked              (GtkButton   *button,
                                        gpointer         user_data);

void
on_save_button_clicked                  (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

void
on_cancel_button1_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_cancel_button1_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_ok_button1_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_cancel_button2_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_about_button_clicked                (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

void
on_about_close_button_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_from__sam_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_local_pwdump1_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_remote_pwdump1_activate             (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_remote_cancel_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_remote_ok_button_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_dialog_remote_dump_close            (GtkDialog       *dialog,
                                        gpointer         user_data);

void
on_filechooserdialog1_close            (GtkDialog       *dialog,
                                        gpointer         user_data);

void
on_filechooserdialog2_close            (GtkDialog       *dialog,
                                        gpointer         user_data);

void
on_fileselection_close                 (GtkDialog       *dialog,
                                        gpointer         user_data);

void
on_tablebutton_activate                (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

void
on_table_dialog_destroy                (GtkObject       *object,
                                        gpointer         user_data);

void
on_button_directory_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_tableselection_close                (GtkObject       *object,
                                        gpointer         user_data);

void
on_cancel_ts_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_ok_ts_clicked                       (GtkButton       *button,
                                        gpointer         user_data);

void
on_cancel_table_dialog_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_ok_table_dialog_clicked             (GtkButton       *button,
                                        gpointer         user_data);

void
on_load_single_hash1_activate          (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_cancel_load_hash_dialog_clicked     (GtkButton       *button,
                                        gpointer         user_data);

void
on_ok_load_hash_dialog_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_load_hash_dialog_destroy            (GtkObject       *object,
                                        gpointer         user_data);

void
on_deletebutton_clicked                (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

void
show_readahead_window(int num);

void
show_clean_windows(void);

void 
hide_readahead_window(void);

#ifdef LIVECD
void activate_launch_toggle (void);
#endif

void
on_help_button_clicked                 (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

void
on_help_window_close                   (GtkObject       *object,
                                        gpointer         user_data);

int change_tree(int hash);

void show_dialog(char *title, char *body);

int extract_hashes_from_dir(char *dir);
